package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````W!<``#0```!$P0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```0````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````**\`
M`"BO```%`````!````$```#`O0``P,T``,#-``!0`@``E!(```8`````$```
M`@```,B]``#(S0``R,T```@!```(`0``!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&04H0``%*$``!2A``#T````]`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP+T`
M`,#-``#`S0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#`````@`````````$````%`````,```!'
M3E4`!DT&M)DXE[6`E^9_66#"TT=_A>T1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````.K3[PYNQ=\?SMY'+6M_FGPNQ9NVU&34?"#_Y`ZYC?$.V7%8'.)'Q@&R
M`8MOK$OCP,+E/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-
MXYX,.I<+6>CM['^IG)OAIP(*H^#[20`````````````````````#`@``````
M```````2````=P(`````````````$@```&("`````````````!(````,`0``
M```````````2````DP``````````````$@````$!`````````````!$```"U
M`@`````````````2````DP$`````````````$@```*`"`````````````!(`
M```B`0`````````````2````$0``````````````(````&@"````````````
M`!(```#6`@`````````````2````!`,`````````````$@```#,"````````
M`````!(```#B`0`````````````2````4P$`````````````$@```+0`````
M`````````!(```!#`0`````````````2````-0$`````````````$@```$@#
M`````````````!(```#W`@`````````````2````[P$`````````````$@``
M`.H!`````````````!(````@```````````````@````L0$`````````````
M$@```!$!`````````````!(```##`@`````````````2````.@,`````````
M````$@```#P``````````````"````#.`@`````````````2````5@``````
M````````$@```(,!`````````````!(```!S```````````````2````\```
M````````````$@```(0``````````````!(````+`P`````````````2````
MX`(`````````````$0```*X"`````````````!(```",`@`````````````2
M````6P(`````````````$@```!H$`````````````!(```#4````````````
M```2````YP(`````````````$@```%P#`````````````!$```!U`0``````
M```````2````4@(`````````````$@```!0"`````````````!(```!G`0``
M```````````2````DP(`````````````$@```*H!`````````````!(````6
M`0`````````````2````9`,`````````````$@```)H"`````````````!(`
M``!;`P`````````````A````A0(`````````````$@```.X"````````````
M`!(````R`P`````````````2````GP``````````````$@```)X!````````
M`````!(````D`P`````````````2````6@,`````````````$0```'`"````
M`````````!(```!*`@`````````````2````VP$`````````````$@```.,`
M`````````````!$```"\`0`````````````1````7`$`````````````$@``
M`&0``````````````!(```!^`@`````````````2````00,`````````````
M$@```!4#`````````````"(```!%`@`````````````2````P@``````````
M````$@```+4#``#$80```````!(`#P`C!```D&```&\````2``X`5`0``)!/
M``!A#0``$@`.`%4#``"@%0``/`(``!(`#@"-`P``\$@```4````2``X`P@,`
M``!=``"&`P``$@`.`',$````20``!0(``!(`#@`^!```G!$````````2``L`
M?`,``!#0````````$``8`)X#```02P``*@```!(`#@#8`P```$X``'8````2
M``X`)`(``-QA```$````$0`0`#P$``"01P``.P```!(`#@"(`P``5.``````
M```0`!@`800``,!.``#'````$@`.`"\$````T````````!``%P#\`P``0$L`
M`.<````2``X`=0,``!#0````````$``7`(`$```,T```!````!$`%P"K`P``
MH&$```(````2``X`-00``-P7````````$@`.`$0$``!`80``70```!(`#@`Q
M!````-`````````@`!<`NP,``-AA```$````$0`0``@$``"`3@``-````!(`
M#@#F`P``,$@``+D````2``X`B@0``#!,``#$`0``$@`.``!L:6)P97)L+G-O
M+C4N,C8`7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A
M8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T
M`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T
M<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/
M7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`&-L
M;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R
M9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`
M;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T
M870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C
M:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M
M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O
M;@!?7W-T86-K7V-H:U]F86EL`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?
M9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?;&EB8U]C<W5?:6YI=`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?
M,BXQ+C,`1TQ)0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C```````@`#``,`````````!`````0```````,`!0`#
M``8`!P````````````,`!``"``(```````,`!0`#`````P``````````````
M!0`#``,``P`#``,````#``,````#``(````#``,````(``,``P`#``,``P``
M````!``#``,``P`'`````````````P`#``D``P````$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`````0`&
M`!H"```0````<````',?:0D```D`EP0``!`````4:6D-```(`*,$```0````
M<AEI"0``!@"M!```$````!)I:0T```4`N00``!````!T&6D)```$`,,$```0
M````$&EI#0```P#/!`````````$``@#+`0``$``````````2:6D-```'`+D$
M```0````$&EI#0```@#/!````````,#-```(````Q,T```@```#\SP``"```
M``30```(````#-````@```#,SP``!@8``-#/```&"@``U,\```8+``#8SP``
M!AD``-S/```&'@``X,\```8A``#DSP``!B(``.C/```&)@``[,\```8M``#P
MSP``!D(``/3/```&0P``^,\```9(``#<S@``!P$``.#.```'`@``Y,X```<#
M``#HS@``!P0``.S.```'!0``\,X```<'``#TS@``!P@``/C.```'"0``_,X`
M``<,````SP``!PT```3/```'#@``",\```</```,SP``!Q```!#/```'$0``
M%,\```<2```8SP``!Q,``!S/```'%```(,\```<5```DSP``!Q8``"C/```'
M%P``+,\```<8```PSP``!QH``#3/```'&P``.,\```<<```\SP``!QT``$#/
M```''P``1,\```<@``!(SP``!R,``$S/```')```4,\```<E``!4SP``!R<`
M`%C/```'*```7,\```<I``!@SP``!RH``&3/```'*P``:,\```<L``!LSP``
M!RX``'#/```'+P``=,\```<P``!XSP``!S$``'S/```',@``@,\```<S``"$
MSP``!S0``(C/```'-0``C,\```<V``"0SP``!S@``)3/```'.0``F,\```<Z
M``"<SP``!SL``*#/```'/```I,\```<]``"HSP``!S\``*S/```'0```L,\`
M``=!``"TSP``!T0``+C/```'10``O,\```=&``#`SP``!T<``,3/```'20``
MR,\```=*``!3@^P(Z'L&``"!PRN]``"+@P0!``"%P'0%Z-8#``"#Q`A;PP#_
MLP0```#_HP@`````````_Z,,````:`````#IX/____^C$````&@(````Z=#_
M____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C'````&@@````
MZ:#_____HR````!H*````.F0_____Z,D````:#````#I@/____^C*````&@X
M````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I4/____^C-```
M`&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&````#I(/____^C
M0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````:'@```#I\/[_
M__^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4````:)````#I
MP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O___Z-@````:*@`
M``#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP_O___Z-L````
M:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT````.E`_O___Z-X
M````:-@```#I,/[___^C?````&C@````Z2#^____HX````!HZ````.D0_O__
M_Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP```!H``$``.G@
M_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____HY@```!H&`$`
M`.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]____HZ0```!H
M,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``Z6#]____H[``
M``!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8`0``Z3#]____
MH[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ````&AP`0``Z0#]
M____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^CT````&B(`0``
MZ=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S___^CW````&B@
M`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I@/S___^CZ```
M`&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!``#I4/S___^C
M]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z,$`0``9I#_HR@!``!F
MD(U,)`2#Y/#_<?Q5B>575E-1B<_H:`(``('#&+D``(/L+(M!!(E%U(M!"(E%
MT&6A%````(E%Y#'`C4704(U%U%!1Z%K___^+@P`!``"#Q`Q04/^S%`$``.@4
M2P``BX,@`0``@\00@#@`#X0B`0``B[/\````@^P,_S;HXOS__X"(_@(```):
M_S;HT_S__X"(_@(```&+!X/$$(/`!3W___\_#X=5`0``@^P,P>`"4.B-_O__
MBW74BP^#Q!")@W01``#'@W@1```$````BQ:#^0&)$(V3X)3__XE0!(N3/`$`
M`(E0"(V3XY3__XE0#'X7N@$```"-="8`BSR6B7R0#(/"`3G1=?*#[`S'1(@,
M`````(/!`VH`4(V#`'G__U%0_[.`$0``Z&;[__^#Q""%P(G&#X2M````@^P,
M_[.`$0``C7W@Z%C]__^-@["3__^)^N@+*@``@\00A<!T;8/L#/^S@!$``.CV
M^O__Z&'\__^#Q!")\(M-Y&4S#10````/A:D```"-9?!96UY?78UA_,/HZ_O_
M_X7`B8.`$0``#X2/````@^P,4.A$_/__B[/\````6?\VZ*;[__^#Q!#&@'$%
M````Z:O^__^+@WP1``"%P'0]@^P,4.@420``@\00Z7C___^#[`S_LX`1``#H
M#OO__X/$$(G&Z3O___]04(V#8I/___^S)`$``%#H(/W__XV#99/__XGZZ$,I
M``"%P(F#?!$```^$,?___^NFZ-Y)``"#[`QJ`>B4_?__,>U>B>&#Y/!05%+H
M(@```('#Y+8``(V#T)+__U"-@W"2__]045;_LRP!``#HT_K___2+'"3#9I!F
MD&:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.0```"!PINV``"-BD`!``"-
M@D`!```YR'0=BX((`0``A<!T$U6)Y8/L%%'_T(/$$,G#D(UT)@#SPXVV````
M`.BD````@<);M@``58V*0`$``(V"0`$``"G(B>53P?@"B<.#[`3!ZQ\!V-'X
M=!2+D@P!``"%TG0*@^P(4%'_TH/$$(M=_,G#B?:-O"<`````58GE4^A7____
M@<,'M@``@^P$@+M0`0```'4GBX,H`0``A<!T$8/L#/^S-`$``.BE_/__@\00
MZ#7____&@U`!```!BUW\R<.)]HV\)P````!5B>5=Z5?___^+%"3#9I"055>-
M:#A64X'L#`,``(U,)'B)1"14B70D$&6+'10```")G"3\`@``,=N)3"0(B7PD
M%(VT)@````"+5)T`BT2=!,=$V00`````QT39#`````#'1"0$``````_*B00D
MB139B<+!Z!C!Z@B!X@#_```)T(L4)(G'BP0DP>(8P>`("=<E``#_``GXB439
M"(/#`H/[$'6EBT0D"(V4)'@"``")%"2)Q9"-="8`BU5HBT5L@\4(,U4X,T4\
M,U4(,T4,,U7X,T7\QT5\`````(G'B=")T0^L^!\!T0G!B4UX.RPD=<B+7"14
MBU,,BTL<BS.+>P2+0PB)5"0<BU,4B4PD#(M+)(E$)!B+0Q")5"0$BU,8B4PD
M7(E\)!2)!"2)5"0(BU,@BUPD!(E4)%B)\L'F!8G1B?6+="18#ZSY&XM\)`B)
M5"00"<T#="1XB>B)\8MT)`R!P9EY@EH!R(L,)#'>(W0D'#'/BTPD&(ET)"`A
MSXG^BWPD"#'^`?")1"0@BWPD&(ML)!R+!"2+5"0$QT0D)`````")^8G^QT0D
M/``````/K.X"P>$>B<>+1"00B<V+3"0(QT0D+``````)]0.,)(````")UHEL
M)#");"0XQT0D1`````"!P9EY@EHC="04,>\AQXET)"B)_HL\)#'^BWPD)`'Q
MBW0D((G]B?")]\'@!8E$)"B+="0H#ZSO&XML)!0)_HM\)!")\(LT)`'(B40D
M*(GYB?@/K.@"P>$>BWPD!(G-BTPD,`G%`[0DB````!.\)(P```");"1`B?"+
M="0@!9EY@EJ)^HM\)#B#T@`QZ3';(<['1"1,`````,=$)#P`````,?>)_HG?
MBUPD.`'&BT0D*!'7BU0D+(ET)#")?"0TBWPD)(G&QT0D-``````/K-`;P>8%
MBU0D+(G!"?&+="0@B<@#1"0PB?$/K/X"P>$>B40D,(M\)#`)\0.<))````")
M3"1@B4PD2(G8!9EY@EHQS2-L)"@S;"1`B>F+;"0T`<&)^,'@!8E$)""+="0@
M#ZSO&PG^B?`!R#'_B<:+1"0HB<'!X1X/K-`"B<V+5"1`BTPD8`G%`Y0DF```
M`(EL)#B);"1`B=`%F7F"6C'I(TPD,(ML)$B+5"0TQT0D)`````#'1"0T````
M`,=$)$0`````,<V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)"@+;"0HB>B+
M;"1``<B)1"0@BT0D,(G!#ZS0`L'A'HM4)$P)P8M$)$@#A"2@````$Y0DI```
M`(E,)#")3"1(!9EY@EJ#T@`QS3';(?4S;"0XB>D!P8M$)"`1TXM4)"2)3"0H
MB5PD+,=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;B?$)U8GH`T0D*,'A
M'@^L_@*)S0GUB40D*(EL)$"+7"0X`YPDJ````(MT)#P3M"2L````BTPD2(G8
MB?*+="0@!9EY@EJ#T@`QZ3';B=\ASC-T)#`!QHM$)"@1UXM4)"R)="0XB7PD
M/,=$)#P`````B<8/K-`;P>8%BU0D),=$)"0`````B<$)\8G(`T0D.#'_B<:+
M1"0@B<$/K-`"P>$>BU0D+`G!BT0D,`.$)+````")3"0XB4PD2`69>8):,<TC
M;"0H,VPD0(GI`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D
M((M$)"B)P<'A'@^LT`*)S0G%B6PD,(M4)$`#E"2X````BTPD1!.,)+P```#'
M1"0T`````,=$)$0`````B=`%F7F"6HG*BTPD2(/2`(E$)"@QVXE4)"R+5"0X
M,>DA\3'*B=`#1"0HB=H35"0LB40D*(M$)"")5"0LBU0D),=$)"P`````B<'!
MX06)3"1`B=&)P@^LRAN+3"1`B50D2`M,)$B)R`-$)"B)\0^L_@+!X1X)\8E$
M)"B+1"0X`X0DP````(E,)$")3"1(!9EY@EHQS2-L)"`S;"0PBWPD*(M4)"3'
M1"0\`````,=$)"0`````QT0D-`````")Z8ML)"P!P8GXP>`%B40D.(MT)#@/
MK.\;"?Z)\`'(,?^)QHM$)"")P<'A'@^LT`*)S8M4)#"+3"1("<4#E"3(````
MB6PD.(EL)$B)T(M4)"P%F7F"6C'I(TPD*(ML)$`QS8GI`<&)\,'@!8E$)"")
M\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P0^LT`+!X1Z+5"1$"<&+
M1"1``X0DT````!.4)-0```")3"0PB4PD8(ML)$C'1"1$``````69>8):@](`
M,<TQVR'U,VPD.(GI`<&+1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L````
M`,'A!8E,)$")T8ML)$")P@^LRAN)\0G5B>@#1"0HP>$>#ZS^`HG-BTPD8`GU
M`YPDV````(MT)#P3M"3<````B40D*(EL)$")V(GRBW0D(`69>8):@](`,>DQ
MVXG?(<XS="0P`<:+1"0H$=>+5"0LB70D.(E\)#S'1"0\`````(G&#ZS0&\'F
M!8M4)"2)P0GQB<@#1"0X,?^)QHM$)"")P0^LT`+!X1X)P8E,)#B+1"0P`X0D
MX````(E,)$B+5"0LQT0D)`````#'1"0T``````69>8):,<TC;"0H,VPD0(GI
M`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D,`ML)#")Z`'(B40D((M$)"B)P<'A
M'@^LT`*)S8M4)$"+3"1$"<4#E"3H````$XPD[````(EL)#")T`69>8):B<J+
M3"1(@](`B40D*#';B50D+(M4)#@QZ2'Q,<J)T`-$)"B)VA-4)"R)1"0HBT0D
M((E4)"R+5"0DB<'!X06)3"1`B=&)P@^LRAN+3"1`BUPD.(E4)$@+3"1(QT0D
M+`````"+5"0DQT0D1`````#'1"0\`````(G(B?$#1"0H#ZS^`L'A'@GQ`YPD
M\````(E$)"B+?"0HB4PD2(E,)$")V`69>8):,<TC;"0@,VPD,(GIBVPD+`'!
MB?C!X`6)1"0XBW0D.`^L[QL)_HGP`<@Q_XG&BT0D((G!P>$>#ZS0`HG-BU0D
M,(M,)$@)Q0.4)/@```");"0XB6PD2(G0!9EY@EHQZ2-,)"B+;"1`,<V)Z0'!
MB?#!X`6)1"0@B?`/K/@;B40D,(ML)"`+;"0PBU0D+,=$)"0`````QT0D-```
M``")Z(ML)$@!R(E$)""+1"0HB<$/K-`"P>$>BU0D1,=$)$0`````"<&+1"1`
M`X0D``$``!.4)`0!``")3"1@B4PD,`69>8):@](`,<TQVR'U,VPD.(GI`<&+
M1"0@$=.+5"0DB4PD*(E<)"R+7"0XB<''1"0L`````,'A!8E,)$")T8ML)$")
MP@^LRAN+3"1@"=6)\HGH`T0D*,'B'@^L_@*)U0GU`YPD"`$``(E$)"B);"1`
MB6PD8(MT)""+5"0LB=@%F7F"6C'I(<XS="0PB?$!P8M$)"B)Q@^LT!O!Y@6+
M5"0DQT0D)`````")1"0XBVPD.(M$)"`)]0'I,?^+;"1@B<Z)3"1(B<'!X1X/
MK-`"B<N+5"0P"<,#E"00`0``B5PD,(G0BU0D1`69>8):,=TC;"0H,VPD0(M<
M)"R)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)#@+;"0X`>F)3"1@B4PD((M,
M)"B)R,'@'@^LV0*)Q8M$)$`)S0.$)!@!``"+3"0P$Y0D'`$``(EL)#@%H>O9
M;H/2`#'IBVPD2#';QT0D-``````QS8GI`<&+1"0@$=.+5"0DB4PD*(E<)"R)
M\\=$)"P`````B<'!X06)3"1`B=&+;"1`B<(/K,H;BTPD*`G5B?(!Z<'B'HG5
MBY0D(`$``(E,)$@/K/L"B4PD*(M,)#`)W8'"H>O9;HM<)"R)T(EL)$"+5"0D
M`<@S;"0XB>F+;"1@,<V+3"0HB>X!QHG(P>`%B40D,(M$)""+;"0P#ZS9&XGS
M"<V)P0'KP>$>#ZS0`HG-BY0D*`$``(E<)#`)Q8M$)#B)7"1@B>^+;"1`@<*A
MZ]ENB7PD.`'0,?V+?"0PB>Z+;"1(,?6)Z8ML)#0!P8GXP>`%B40D((MT)"`/
MK.\;BT0D*(M4)"P)_L=$)"0`````QT0D+``````!\8E,)$B)3"0@B<'!X1X/
MK-`"B<V+C"0P`0``BU0D)`G%BT0D0(GNBVPD.('!H>O9;HET)$`!R#'UB>Z+
M;"1@,?6)Z0'!BT0D((G&#ZS0&\'F!8M4)#2)1"0HBVPD*(M$)#`)]0'I,?^)
MSHE,)&")P<'A'@^LT`*)RXN4)#@!```)PXM$)#B)W8E<)#B+7"1`@<*AZ]EN
M`="+5"0D,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0P
MBT0D(`'IB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)$`!``"+C"1$`0``
MBT0D0(ML)#B!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';
MB=F+1"0HBYPD2`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````
MP>$%B4PD0(G1BVPD0(G"BT0D.`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQ
MP>$>#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$
M)"")RXG&#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)
MWL=$)"P`````#ZS0`HN4)%`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+
M5"0D,>F+;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D
M(`'IB4PD*(E,)&")P<'A'@^LT`*+E"18`0``B<V+C"1<`0``"<6+1"0XB6PD
M,(ML)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+
M1"0H,>H#5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPD
M8`$``(M$)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"1(B4PD((GQP>$>
M#ZS^`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD8#'UB>D!P8M$)"")
MQ@^LT!O!Y@6+5"0LQT0D+`````")1"1`BVPD0(M$)"@)]0'I,?^)SHE,)&")
MP<'A'@^LT`*)RXN4)&@!```)PXM$)#")W8E<)$"+7"0X@<*AZ]EN`="+5"0D
M,>N+;"1(,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)#`+;"0PBT0D(`'I
MB4PD2(E,)"B)P<'A'@^LT`*)S0G%B6PD,(N4)'`!``"+C"1T`0``BT0D.(ML
M)$"!PJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D8#';B=F+1"0H
MBYPD>`$``#'J`U0D(!-,)"2)5"0@BU0D+(E,)"2)P<=$)"0`````P>$%B4PD
M.(G1BVPD.(G"BT0D0`^LRAN+3"0@"=6+5"0D`>F)3"0@B4PD8(GQP>$>#ZS^
M`HG-"?6!PZ'KV6Z)[XML)#`!V(E\)#@Q_8GNBVPD2#'UB>D!P8M$)"")RXG&
M#ZS0&\'F!8E$)$"+;"1`BT0D*`GU`>N)P3'_B5PD2(M4)"S!X1Z)WL=$)"P`
M````#ZS0`HN4)(`!```)P8M$)#")S8M,)#B!PJ'KV6Z);"1``="+5"0D,>F+
M;"1@,<V)Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)#`+;"0PBT0D(`'IB4PD
M*(E,)&")P<'A'@^LT`*+E"2(`0``B<V+C"2,`0``"<6+1"0XB6PD,(ML)$"!
MPJ'KV6Z#T0")RXG1,=(!R!':,VPD,(E$)"")5"0DBU0D2#';B=F+1"0H,>H#
M5"0@$TPD)(E4)""+5"0LB4PD)(G!P>$%B4PD.(G1BVPD.(G"BYPDD`$``(M$
M)$`/K,H;BTPD(,=$)"0`````"=6+5"0D`>F)3"0@B4PD.(GQP>$>#ZS^`HG-
M"?6!PZ'KV6Z)[XML)#`!V(E\)$`Q_8GNBVPD8#'UB>D!P8M$)"")Q@^LT!O!
MY@6+5"0LQT0D+`````")1"1(BVPD2(M$)"@)]0'I,?^)SHE,)&")P<'A'@^L
MT`*+E"28`0``B<N+C"2<`0``"<.+1"0PB=V!PJ'KV6Z);"1(@]$`B<N)T3'2
M`<@1VHM<)$`QZXML)#@QW3';B>D!P8GP$=/!X`4QTHE$)"B)\(ML)"@/K/@;
MB40D,`ML)#"+1"0@`>D1TXG*B<&)7"1LB50D:,'A'HE4)"B+5"0DB<V+C"2D
M`0``QT0D-``````/K-`"BY0DH`$```G%BT0D0(EL)#B+;"1(@<*AZ]EN@]$`
MB<N)T3'2`<@1VC-L)#B)1"0@B50D)(M4)&`QVXG9BT0D*(N<)*@!```QZ@-4
M)"`33"0DB50D((M4)"R)3"0DB<'!X06)3"0PB=&+;"0PB<*+1"1(#ZS*&XM,
M)"`)U0'IB4PD,(E,)$")\<'A'@^L_@*)S8M\)#`)]8'#H>O9;@'8BUPD.(EL
M)&`QZXML)&@QW8GIBVPD-`'!B?C!X`6)1"0@BW0D(`^L[QL)_HGP`<B)1"0@
MBT0D*(M4)"R+="1@BWPD0,=$)"0`````B<''1"0L`````,=$)$P`````#ZS0
M`L'A'HN4)+`!``")\XG-QT0D/``````)Q8M$)#B!PJ'KV6Z);"1(`=`QZXM4
M)"0QWXN<)+P!``")^0'!BT0D(,'@!8E$)"B+1"0@BWPD*`^LT!N+5"0TB40D
M.`M\)#B)^`'(B40D*(M$)#")P0^LT`+!X1X)P8GPB<^)3"0XBXPDN`$``('!
MW+P;CX/3`#'2`<B+3"1($=H)_2-L)"`QVR'YB<X)[HGQ`<&+1"0H$=.+5"0L
MB4PD,(E<)#2)P<'A!8E,)$")T8ML)$")P@^LRAL)U8GH`T0D,(M4)"0QVXMT
M)$C'1"0T`````,=$)$0`````B40D,(M$)"")P<'A'@^LT`*)S8GYB?H)Q8M$
M)"@)Z2'JB6PD0"'(B<<)UP.T),`!``")^8M\)$P3O"3$`0``QT0D3`````")
M\(G.!=R\&X^)^HG?@](``<:+1"0P$=>+5"0TB70D((E\)"2)Q@^LT!O!Y@6+
M5"0LB<$)\8G(`T0D(#'_B<:+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)$@C
M;"0PB4PD8(M,)$`AT0G-`X0DR`$``(GI!=R\&X\!P8GPP>`%B40D((GP#ZSX
M&XE$)"B+;"0@"VPD*(M4)#3'1"0D`````,=$)#0`````QT0D/`````")Z`'(
M,=N)1"0@BT0D,(G!P>$>#ZS0`HM4)&")S0G%B6PD,`GJB="+5"1((?`AZ@G0
MBU0D1(G!BT0D0`.$)-`!```3E"34`0``!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&)P@^LRAN+3"0XB50D0`M,)$")
MR`-$)"B)\<'A'HE$)"B)\`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1@BW0D
M2(M4)"3'1"1$``````G]`[0DV`$``(M\)"B)Z8ML)"R)\`7<O!N/`<&)^,'@
M!8E$)$"+="1`#ZSO&PG^B?`!R#'_,=N)QHM$)"")P<'A'@^LT`*)S8M4)&`)
MQ8M$)"B);"1`">HAT(M4)#@AZ@G0BU0D-,=$)#0`````B<&+1"0P`X0DX`$`
M`!.4).0!```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPBU0D+`^L^!N)7"0D
MQT0D)`````")1"0P"TPD,(G(`T0D(#';B40D((M$)"B)P0^LT`+!X1X)P8G*
M"<V)3"0PB4PD2(M,)$`A]8M$)#@AT8M4)#S'1"0\``````G-`X0DZ`$``!.4
M).P!``")Z07<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L`````(G!
MP>$%B4PD.(G1BVPD.(G"#ZS*&XGQ"=6+5"1(B>@#1"0HP>$>B<TQVXE$)"B)
M\(MT)$`/K/@""<6+1"0@">J);"0X(="+5"0PB<<AZ@G7`[0D\`$``(GYBWPD
M1!.\)/0!``")\(G.!=R\&X^)^HG?@](``<:+1"0H$=>+5"0LB70D0(E\)$2)
MQ@^LT!O!Y@6)P0GQB<@#1"1`,?^)QHM$)""+5"0DQT0D)`````#'1"1$````
M`,=$)#0`````B<$/K-`"P>$>"<&+1"0PB<J)3"1`B4PD2`G-BTPD."-L)"@A
MT8M4)"P)S0.$)/@!``")Z07<O!N/`<&)\,'@!8E$)"")\(ML)"`/K/@;B40D
M,`ML)#")Z`'(,=N)1"0@BT0D*(G!P>$>#ZS0`HM4)$B)S0G%B6PD,`GJB="+
M5"1`(?`AZ@G0BU0D/(G!BT0D.`.$)``"```3E"0$`@``!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0HB5PD+(G!P>$%B4PD.(G1B<(/K,H;B50D2(M,)#@+3"1(
MQT0D+`````"+5"0DQT0D/`````#'1"1$`````(G(`T0D*(GQP>$>B40D*(GP
MBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0(`@``BWPD*(GI
MBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(,?\QVXG&BT0D
M((G!P>$>#ZS0`HG-BU0D2`G%BT0D*(EL)$`)ZB'0BU0D."'J"="+5"0TB<&+
M1"0P`X0D$`(``!.4)!0"```%W+P;CX/2``'!B?`1T\'@!8E,)"")P8GPB5PD
M)`^L^!N)1"0P"TPD,(M4)"S'1"0D`````,=$)#0`````B<@#1"0@,=N)1"0@
MBT0D*(G!#ZS0`L'A'@G!BT0D.(G*B4PD,(E,)$@)S8M,)$`A]2'1BU0D/,=$
M)#P`````"<T#A"08`@``$Y0D'`(``(GI!=R\&X^#T@`!P8M$)"`1TXM4)"2)
M3"0HB5PD+,=$)"P`````B<'!X06)3"0XB=&+;"0XB<(/K,H;B?$)U8M4)$B)
MZ`-$)"C!X1Z)S3';B40D*(GPBW0D0`^L^`()Q8M$)"`)ZHEL)#@AT(M4)#")
MQR'J"=>)^8M\)$0#M"0@`@``$[PD)`(``,=$)#0`````B?")S@7<O!N/B?J)
MWX/2``'&BT0D*!'7BU0D+(ET)$")?"1$QT0D1`````")Q@^LT!O!Y@6+5"0D
MQT0D)`````")P0GQB<@#1"1`,?^)QHM$)"")P0^LT`+!X1X)P8M$)#")RHE,
M)$")3"1("<V+3"0X(VPD*"'1BU0D+`G-`X0D*`(``(GI!=R\&X\!P8GPP>`%
MB40D((GPBVPD(`^L^!N)1"0P"VPD,(GH`<@QVXE$)""+1"0HB<'!X1X/K-`"
MBU0D2(G-"<6);"0P">J)T(M4)$`A\"'J"=")P8M$)#@#A"0P`@``BU0D/!.4
M)#0"``#'1"0\``````7<O!N/@](``<&+1"0@$=.+5"0DB4PD*(E<)"S'1"0L
M`````(G!P>$%B4PD.(G1B<(/K,H;BTPD.(E4)$@+3"1(BU0D)(G(`T0D*(GQ
MP>$>B40D*(GPBW0D0`^L^`*+?"0P"<$)S2-L)"")3"0X(<^)3"1("?T#M"0X
M`@``BWPD*(GIBVPD+(GP!=R\&X\!P8GXP>`%B40D0(MT)$`/K.\;"?Z)\`'(
M,?\QVXG&BT0D((G!P>$>#ZS0`HG-"<6);"1`QT0D1`````"+5"1(BT0D*`GJ
M(="+5"0X(>H)T(M4)#2)P8M$)#`#A"1``@``$Y0D1`(```7<O!N/@](``<&)
M\!'3P>`%B4PD((G!B?"+5"0L#ZSX&XE<)"3'1"0D`````(E$)#`+3"0PQT0D
M+`````")R`-$)"`QVXE$)""+1"0HB<$/K-`"P>$>"<&+1"0XB<H)S8E,)"B)
M3"1@BTPD0"'U(=&+5"0\"<T#A"1(`@``$Y0D3`(``(GI!=R\&X^#T@`!P8M$
M)"`1TXM4)"2)3"0PB5PD-(G!P>$%B4PD.(G1BVPD.(G"B?#'1"0T``````^L
MRAN+3"0PQT0D/``````)U8M4)&`!Z8E,)$B)3"0PB?$/K/@"P>$>BW0D0(G-
M"<6+1"0@">J);"1HB6PD."'0BU0D*(G'(>H)UP.T)%`"``"+5"0TB?F)\`7<
MO!N/`<&+1"0PB<N)Q@^LT!N+5"0DP>8%B40D0(ML)$"+1"0@"?4!ZXG!,?\/
MK-`"P>$>BU0D+(ML)&@)P8M$)"@#A"18`@``$Y0D7`(``(E<)&")WHE,)$`%
MUL%BRH/2`#'-B40D((E4)"2+5"1(B=@QZHG1`TPD(,'@!8E$)"")V(ML)"`/
MK/@;BU0D-(M<)$")1"0H"VPD*(M$)##'1"0D``````'IB4PD((E,)$B)P<'A
M'@^LT`*)S8M4)#P)Q8M$)#@#A"1@`@``$Y0D9`(``(EL)#@%UL%BRH/2`#'K
MBVPD8#'=,=N)Z0'!BT0D(!'3BU0D)(E,)"B)7"0LB?/'1"0L`````(G!P>$%
MB4PD,(G1BVPD,(G"#ZS*&XM,)"@)U8GR`>G!XAZ)U8N4)&@"``")3"1@#ZS[
M`HE,)"B+3"1`"=V!PM;!8LJ)T(EL)$`!R#-L)#B)Z8ML)$B+7"0LBU0D),=$
M)#0`````QT0D)``````QS8M,)"B)[@'&B<C!X`6)1"0PBT0D((ML)#`/K-D;
MB?.+="1`"<V)P0'KP>$>#ZS0`HG-BY0D<`(``(E<)#`)Q8M$)#B+?"0PB6PD
M.(E<)$B!PM;!8LH!T#'NBVPD8(M4)"PQ]8GIBVPD-`'!B?C!X`6)1"0@BW0D
M(`^L[QN+1"0H"?X!\8MT)#B)3"0@B4PD8(G!P>$>#ZS0`HG-BXPD>`(``(M4
M)"0)Q8M$)$")[XGU@<'6P6+*B7PD.`'(,?TS;"1(B>D!P8M$)"#!X`6)QXM$
M)"`/K-`;B40D*(ML)"B+1"0PBU0D-,=$)"P`````QT0D-``````)_0'IB4PD
M2(E,)"B)P0^LT`*+E"2``@``P>$>B<T)Q8GP@<+6P6+*B6PD0`'0,VPD.(M4
M)"PS;"1@B>D!P8M$)"B)RXG&B<>+1"0XP>8%B70D,(ML)#`/K-<;"?V+?"0@
M`>N+;"0DQT0D)`````")7"0PB5PD8(GZB?Z+?"0T#ZSN`L'B'HG5BY0DB`(`
M``GUBW0D0(EL)#B!PM;!8LH!T#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`6)
M1"0@BW0D(`^L[QN+1"0H"?X!\8E,)$B)3"0@B<&+5"0LP>$>BWPD.(G-QT0D
M+``````/K-`"BY0DD`(```G%BT0D0(GNB?V!PM;!8LJ)="0X`=`Q]3-L)&"+
M5"0DB>D!P8M$)"")R\'@!8E$)"B+1"0@BVPD*`^LT!N+5"0TQT0D-`````")
M1"1`"VPD0(M$)#`!ZXG!#ZS0`HN4))@"``#!X1Z)7"0HB<V)7"1@"<6)^('"
MUL%BRHEL)$`!T#-L)#B+5"0L,VPD2(GI`<&+1"0HB<:)Q\'F!8ET)#"+;"0P
M#ZS7&PG]BWPD(`'IBVPD)(E,)$B)3"0PB?J)_@^L[@+!XAZ)U8N4)*`"``"+
M1"0X"?6+="1`BWPD-(EL)#C'1"0D`````('"UL%BR@'0,>Z+;"1@BU0D+,=$
M)"P`````,?6+="0PB>F)_0'!B?")]XG+P>`%B40D((M$)"B+="0@#ZSO&XG!
M"?Z+?"0X`?/!X1X/K-`"B<V+E"2H`@``B5PD(`G%BT0D0(E<)&")[HG]@<+6
MP6+*B70D:`'0,?4S;"1(BU0D)(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0
M&XM4)#2)1"0X"VPD.(M$)#`!Z8E,)$")3"0HB<$/K-`"BY0DL`(``,'A'HG-
M"<6)^('"UL%BRHEL)#@!T#'U,VPD8(M4)"S'1"0T`````(GI`<&+1"0HB<N)
MQHG'BT0D:,'F!8ET)#"+;"0P#ZS7&PG]BWPD(`'KBVPD),=$)"0`````B5PD
M,(E<)$B)^HG^BWPD-`^L[@+!XAZ)U8N4)+@"```)]8MT)#B);"1H@<+6P6+*
M`=`Q[HML)$"+5"0L,?6+="0PB>F)_0'!B?")]\'@!8E$)""+="0@#ZSO&XM$
M)"@)_HM\)&@!\8E,)"")3"1@B<'!X1X/K-`"B<V+E"3``@``"<6+1"0XB>Z)
M_8'"UL%BRHET)#@!T#'U,VPD2(GI`<&+1"0@B<O!X`6)1"0HBT0D((M4)"2+
M;"0HQT0D+``````/K-`;BU0D-,=$)#0`````B40D0(M$)#`+;"1`B<$!Z\'A
M'@^LT`*+E"3(`@``B<V+C"3,`@``"<6)7"1(B5PD*(GXB6PD0('"UL%BRH/1
M`(G+B=$QT@'($=HS;"0X,=LS;"1@B>D!P8M$)"@1TXM4)"R)QHG'BT0D.,'F
M!8ET)#"+;"0P#ZS7&S'2"?V+?"0@`>F+;"0D$=.)3"0PB4PD8(GZB?Z+?"0T
M#ZSN`L'B'HE<)&2)U8N4)-`"```)]8MT)$");"0X@<+6P6+*`=`Q[HML)$@Q
M]8MT)#")Z8G]`<&)\(GWB<O!X`6)1"0@BW0D((M$)"B+5"0L#ZSO&\=$)"0`
M````QT0D+``````)_HG!BWPD.`'SP>$>#ZS0`HN4)-@"``")S8N,)-P"```)
MQ8M$)$")7"0@B5PD2(GNB?V!PM;!8LJ#T0")RXG1,=(!R!':,?4S;"1@,=N)
M="1@B>D!P8M$)"`1TXM4)"3!X`6)1"0HBT0D((ML)"@/K-`;,=*)1"0X"VPD
M.(M$)#`!Z1'3BU0D-(E,)"B)3"1`B<&)7"1$P>$>#ZS0`HN4).`"``")S8N,
M).0"```)Q8GXB6PD.('"UL%BRH/1`(G+B=$QT@'($=HQ]3-L)$@QVXGI`<&+
M1"0H$=.+5"0LB<:)Q\'F!8ET)#"+;"0PB=X/K-<;B<LQTHM$)&`)_8M\)"#'
M1"0T``````'KBVPD),=$)"0`````$=:)7"0PB5PD2(ET)$R)^HG^#ZSN`L'B
M'HM\)$")U8N4).@"```)]8MT)#B);"1@@<+6P6+*`=`Q[HM4)"PQ]XMT)#")
M^8M\)#0!P8GPP>`%B?V)]XE$)""+="0@#ZSO&XML)&`)_HGP`<B)1"0@BT0D
M*(G!#ZS0`L'A'HM4)#`)P8M$)#B)SXM,)#2)TXE\)$#!XQZ)SHE<)"@/I-8>
M#ZS*`L'I`HET)"R)[HE,)#2+C"3P`@``B50D,('!UL%BR@'(,?XS="1(B?$!
MP8M$)"#!X`6)QHM$)""+5"0DBUPD*`^LT!O!ZAN)1"0XBWPD.(E4)#P)]XGX
MBWPD5`'(B<&+1"08`TPD$`-$)"`+7"0PQT<$`````,='#`````#'1Q0`````
MQT<<`````(D/QT<D`````(E'"(G8`P0DB4<0BT0D0`-$)`B)1QB)Z`-$)%B)
M1R"+A"3\`@``93,%%````'4+@<0,`P``6UY?7</HL2```)!55U93Z!?7__^!
MP\>-``"#[!R%P`^$G@```(N+'`$``(L)A<F)3"0(#X2*````#[8(A,ET!8#Y
M/75&,?:+?"0(BR^%[70OB50D#(E$)`1FD(/L!%;_="0,5>BRT___@\00A<!U
M!X!\-0`]="R#QP2++X7M==N#Q!R)Z%M>7UW#D(G&@\8!#[8.A,ET!8#Y/77Q
M*<;KIXUV`(GZ*U0D"(M$)`R-;#4!P?H"B1"#Q!R)Z%M>7UW#C78`,>WKN8UT
M)@!75HG&4^A/U___@<(&C0``@^P0B[H<`0``C5PD"&6A%````(E$)`PQP(G:
MB?#H#O___X7`=#.+5"0(BP>-!)"+4`2%THD0=.&0C;0F`````(/`!(M0!(72
MB1!U](G:B?#HV_[__X7`=<V+1"0,93,%%````'4'@\006UY?P^AN'P``C;0F
M`````(V\)P````!55XG%5E.)UNC#U?__@<-SC```@^PX9:$4````B40D*#'`
M,<"`.CT/E,`!QE;H/M'__X/$$(D$)(GHC50D&.AM_O__A<`/A`T!``"#[`R)
MQU#H&M'__X/$$#L$)`^#W@```(M$)!B-#(4`````BX,<`0``B40D!`^V10"$
MP`^$I0$``#P]#X2=`0``B>CK!I"`^CUT"H/``0^V$(32=?$IZ(M4)`2#[`R+
M.@'/BTPD#(U$"`)0Z%;1__^#Q!"%P(D'#X1U`0``BU0D!(U-`8L"BU0D&(L4
MD`^V10`\/8@"=".$P'4/ZQV)]HV\)P`````\/700@\$!#[9!_X/"`83`B`)U
M[,8"/3'`C;0F``````^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A10!
M``"#Q"Q;7E]=PXVV`````(/&`0^V1O^#QP&$P(A'_W7OZ\R0C70F`(N#'`$`
M`(L0B40D!(LZA?\/A,(````QP.L(C;8`````B?B->`&+#+J%R77TC02%#```
M`(N+<!$``(7)=6N)5"0(@^P,QX-P$0```0```%#H9-#__X/$$(7`#X2%````
MC0R]`````(/L!%&+5"00B4PD%%*)1"044.B;T/__BTPD%(M$)!B#Q!")`8M,
M)`R+1"0(QT2X!`````")?"08Z7S^__^0C70F`(/L"%!2Z/;-__^+3"04B40D
M&(/$$(7`B0%T(8T,O0````#KPHUT)@`QP.ER_O__D+@(````,?_I3____[C_
M____Z=O^___H%1T``)"-="8`55>)Q593Z'73__^!PR6*``"![(P```!EH10`
M``")1"1\,<"%[70&@'T``'4CBT0D?&4S!10````/A2<!``"!Q(P```!;7E]=
MPXVT)@````"#[`Q5Z&?.__^)1"00@\00A<!TR8V#$9/__XE$)`2-@Q"3__^)
M1"0(@^P,_W0D#.A\SO__@\00A<`/A+$```"-4!.+?"0$N0(```")UO.F=->+
M?"0(N0,```")UO.F=,B)5"0,@^P,5>ACSO__BU0D'(G&B10DB50D'.A1SO__
MC40&`HD$).CESO__B<986HM4)!2-@Q.3__]255!J_VH!5NA:S___@\0<C40D
M(%!6:@/HNLS__X/$$(/X_W00BT0D+"4`\```/0!```!T/H/L#%;H"<[__X/$
M$(/L#%;H7<W__X/$$.D]____D(UT)@"#[`S_="0,Z#3.__^)+"3HG,[__X/$
M$.G1_O__B?#HG?[__^O%Z*8;``"-M@````!64XG&Z`?2__^!P[>(``"#['AE
MH10```")1"1P,<"-1"004%9J`^@%S?__@\00A<!U+HM4)!R!X@#P``"!^@!`
M``!T)('Z`*```'0<BTPD;&4S#10```!U)X/$=%M>PY`QP.OHC70F`(/L"&H"
M5NC-S/__@\00A<`/E,`/ML#KS.@;&P``C70F`(V\)P````!55XG'5E/H=='_
M_X'#)8@``('L,!```&6A%````(F$)"`0```QP(E4)`QH_P\``(V#&9/__XUT
M)"164.C0S?__@\00A<`/CHT```"-:/^+D_P```"`?"P<`(L2=%.)Q8E4)`R#
M[`15:B]6Z/'-__^#Q!"%P(M4)`QT/H/L#%+HW<O__U565U#HQ,S__X/$((N$
M)!P0``!E,P44````=4.!Q"P0``!;7E]=PXVV`````(7M=:N-="8`@^P,4NB?
MR___@\0,_W0D#%=0Z&'+__^#Q!#KNXUT)@"+@_P```"+$.O6Z"D:``")]HV\
M)P````!3Z(K0__^!PSJ'``"#[!2+@_P```#_,.A4R___C9,,E?__4HV3*)/_
M__^S$`$``%)0Z&K-__^#Q"A;PY"-="8`5E/H2=#__X'#^88``(/L$(NS_```
M`/\VZ!/+__^)!"3HF____UC_-N@#R___6HV3O93__UEJ`%)2C9,PCO__4HV3
M1)/__U)0Z&/+__^#Q"1;7L.-M@````"-O"<`````55=64^CGS___@<.7A@``
M@>P<(```9:$4````B80D#"```#'`Z(?)__^-DR23__^#[`A24(V#69/__U!H
M`1```&H!C70D)E;H=,S__X/$'&@`$```C;PD$Q```%=6Z![,__^#Q!"%P'A'
MB<:-0`&#[`Q0Z+G+__^#Q!"%P(G%=!.#[`165U#H]<K__\9$-0``@\00BXPD
M#"```&4S#10```")Z'4/@<0<(```6UY?7<,Q[>O?Z,<8``"-M"8`````Z3O_
M__^-="8`C;PG`````%575E/H%\___X'#QX4``('LG!```&6A%````(F$)(P0
M```QP(U$)"R+O"2P$```B[0DM!```(E$)!2)PHV#99/__XE\)`SHM??__X/L
M"(G%:B]7Z!C)__^#Q!"%P'0YBWPD#(V#;I/__XGZZ.#X__^)^(N4)(P0``!E
M,Q44````#X5Z`0``@<2<$```6UY?7<.-M"8`````@^P,_W0D&.@<RO__6EF)
M1"0@C8-[D___B40D&%!6Z.7*__^#Q!"%P(G&=)N`/@"-@Q&3__^)1"0<#X3.
M````B?:-O"<`````A>UT%8/L"%95Z'++__^#Q!"%P`^$B````(/L#%;HOLG_
M_X/$$(!\!O\O=1*-="8`@^@!@'P&_R_&!`8`=/*+3"08C40(`3W_#P``#X\N
M____C8-]D___@^P$_W0D$%"-@WB4__]64&@`$```:@&-M"2H````5NB5RO__
M@\0<_W0D&%9J`^CVQ___@\00A<!U$(M$)#PE`/```#T`@```=$^#[`C_="08
M:@#H$<K__X/$$(7`B<8/A,/^__^`/@`/A3O___^%[707BWPD'+D"````B>[S
MIG3)D(VT)@````"+="0<N`$```#I4/___V:0@^P(:@%6Z'7(__^#Q!"%P'6?
MC8-ND___B?+H8??__X/L#%;H6,K__X/$$.ER_O__Z*L6``"-="8`C;PG````
M`(M4)`0/M@J)T(3)=!N-=@"#P@&`^2\/M@H/1,*$R77P\\.-M@````#SPXVV
M`````%93Z-G,__^!PXF#``"#[!2+="0@A?9T.`^V%H32=#&(5"0/@^P,5NA4
MR/__C40&_X/$$`^V5"0/.<9R"^L^9I"#Z`$YQG0Y@#@O=/3K)V:0C8,1D___
M@^P,4.BQR?__@\00@\046U[#D(VT)@````"`."]T,(/H`3G&<O0YQG4E@/HO
M=,N-@WV3__^#[`Q0Z'S)__^#Q!#KR8VT)@````"`."]U!X/H`3G&<O0I\(U0
M`H'Z`!```'<G@\`!:``0``!05HVS<`$``%;H$<;__X/$$(GP@\046U[#C;8`
M````,<#I>____XGVC;PG`````%=64^CHR___@<.8@@``@^PP9:$4````B40D
M+#'`BX/HE/__C70D!(E$)`J+@^R4__^)1"0.BX/PE/__B40D$HN#])3__XE$
M)!:+@_B4__^)1"0:BX/\E/__B40D'HN#`)7__XE$)"*+@P25__^)1"0F#[>#
M")7__V:)1"0JC8-_D___Z`CU__^-@XB3___H_?3__XV#D)/__^CR]/__C8.9
MD___Z.?T__^-@Z"3___HW/3__XV#L)/__^C1]/__C8-ED___Z,;T__^-@[R3
M___HN_3__XV#QI/__^BP]/__C8/0D___Z*7T__^-@VZ3___HFO3__XV#VI/_
M_XGRZ,WS__^%P'0-B<*-@\:3___H#/7__XV#ZY/__XGRZ*_S__^%P'0-B<*-
M@_V3___H[O3__XV#")3__XGRZ)'S__^%P'0UB<*-@V63___HT/3__XV3-)3_
M_XV#H)/__^B_]/__BT0D+&4S!10```!U48/$,%M>7\.-=@"-@QB4__^)\NA+
M\___A<!U)XUT)!N-NRF4__^Y"@```/.F=;2-5"0EC8.\D___Z'7T___KHXUV
M`(G"C8.\D___Z&/T___KD>B\$P``C;8`````C;\`````4^@:RO__@</*@```
M@^P89:$4````B40D##'`BX,X`0``@_C_=!J+3"0,93,-%````'4^@\086\.0
MC;0F`````(U4)`B-@[R3___HL?+__XG",<"%TG02#[82@/HP#Y7!,<"$T@^5
MP"'(B8,X`0``Z[7H.A,``(UV`(V\)P````!3Z)K)__^!PTJ```"#[`CH;,7_
M_X/L#%#H0\7__X/$$(7`=`R+`(/$"%O#D(UT)@`QP.ORC;8`````C;\`````
M55=64^A7R?__@<,'@```@^P<9:$4````B40D##'`C50D"(V#-I3__XM\)##H
M#_+__X7`=&N`.`")QG1D@^P(5U#H2L7__X/$$(7`=6"#[`Q7Z*K$__^)Q8DT
M).B@Q/__C40%`HD$).@TQ?__B<6-@WN3__^#Q`Q64(V#>)3__U=0:O]J`57H
MI<7__XV#-I3__X/$((GJZ/7R___K$(UV`(V#-I3__XGZZ./R__^+1"0,93,%
M%````'4(@\0<6UY?7</H*1(``(GVC;PG`````%575E/H@,G__X'"-W\``('L
MC($``(N$)*"!``")T8E4)`2-="0PC9E&E/__QX0DF`````````#'A"2\````
M`````,>$)*0`````````B40D$(F<))P```!EH10```")A"1\@0``,<"-@E*4
M__^)A"20````C8(1D___C9+]D___B80DE````(V!]I/__XE4)`R)E"2H````
MB?*)A"2L````C8%7E/__B80DL````(V!$Y3__XF$)+0```"-@5^4__^)A"2X
M````C8%CE/__B80DH````(V!99/__^B0\/__A<!T"8`X``^%<P(``.C^_?__
MA<")Q0^$M`(``(/L#%6+?"04B?OH)</__XU$``&)!"3HN</__XE$)!B#Q!"`
M?0``=$:+1"0$BWPD"(ET)!B-@&R4__^)_HG'C;8`````#[9%`(/L#(/%`5!7
M:O]J`5:+7"0D@\8"Z`/$__^#Q""`?0``==J+="08C9PDJ````(M$)`SK%HGV
MC;PG`````(/#!(L#A<`/A(,!``")\NC<[___A<")QW3F@#@`=.'HW/3__X7`
M=-B#[`Q7BUPD%.@+Q/__@\00A<")Q0^$3@$``(VV`````(GHBPB#P`2-D?_^
M_O[WT2'*@>*`@("`=.F)T<'I$/?"@(````]$T8U(`@]$P8G1`-&+3"0(@]@#
M*>B+&8/!!(V3__[^_O?3(=J!XH"`@(!TZ8G3P>L0]\*`@```#T33C5D"#T3+
MB=,`TX/9`RM,)`B#[`R-O`@$!```5XM<)!3HA,+___]T)!B+3"08B<*-@7&4
M__^)RU"-@7V3__^)1"0P4(V!=I3__U50:O]J`8E4)#12Z.#"__^#Q"AHP`$`
M`/]T)!3HS[___X/$$(/X_W40Z**___^+`(/X$0^%OPD``(/L!%;_="00:@.+
M7"04Z/3`__^#Q!"%P(G%=12+1"1`)0#P```]`$````^$1P$``(/L#/]T)!2+
M1"0@_S"+7"08C8-4E?__4(N#&`$``&H!_S#HL+___X/$(,=$)`P`````ZWN-
M=@`Q_XVV`````(N<O)````"%VW0U@#L`=#")V(/'`>A.\___A<!TXH/L#%.+
M7"04Z'W"__^#Q!"%P'3.B<7I=_[__XVT)@`````Q[>EI_O__D(/L#%")1"08
MZ,/[__^+1"08BUPD%(D$).A#PO__B40D'(/$$(UT)@"+E"1\@0``93,5%```
M`(M$)`P/A;P)``"!Q(R!``!;7E]=PY"-="8`B=@Q_X7`=":0C;0F`````(GR
M@\<!Z*;M__^%P'0%@#@`=2V+A+R<````A<!UXH/L#&H-BWPD%(G[C:]+E/__
MZ-S`__^)1"08@\00Z23]__^#[`Q0BUPD%.BSP?__@\00A<!TOXG%Z>'\__^0
MC70F`(M$)$B+7"0$B40D#.@_P/__.40D#`^%GO[__XM$)$`E_P$``#W``0``
M#X6*_O__@^P,5XM\)!2)^^ARP/__B40D'(V'093__XGRZ`'M__^#Q!"%P`^$
MA@$``(/L#%"+7"04Z#G!__]:65"+1"0<_S#HV_3__XE$)"R#Q!"%P`^$7`$`
M`(/L#(MT)"A6BWPD%(G[Z'F___^#Q!"#^`-V,8GSC;]_E/__C70&_+D%````
M\Z9U'(/X!`^$`P<``(!\`_LO#X3X!@``D(VT)@````#H>_G__X7`=2&#[`AJ
M`/]T)"B+7"04Z(7`__^)1"0L@\00A<`/A?8```"+?"0$C9<TE/__C;>]E/__
MC8>\D___B?OHB>W__^@4O?__5E"-AYB4____="0@_W0D%(V_II3__U!J_VH!
M_W0D*.@`P/__@\0@B70D$(MT)`SK0(UV`(M<)`3HQ[S__X,X$75)BUPD!(/%
M`>C&O/__@^P,_W0D'%50_W0D,/]T)"17:O]J`5:+7"0TZ+:___^#Q#"#[`AH
MP`$``%:+7"04Z*&\__^#Q!"#^/]TJ8/L#/]T)!2+="04B?/HQ[W__XM<)!R-
MAF63__^)VNC6[/__B1PDZ#[Y__^#Q!#ICOW__XVV`````(M$)!"+`(E$)!SI
ME?[__Y!J`FK_:NZ+?"0H5XMT)!2)\^C:O/__@\0,:@:-A"2$`0``B40D&%!7
MZ$.]__^#Q!"`O"1\`0```'4.@+PD?0$``$,/A&4&``!J`&H`:@#_="0HBUPD
M%.B5O/__QX0DT`````$C16?'A"34`````````,>$)-@```")J\WOQX0DW```
M``````#'A"3@````_MRZF,>$).0`````````QX0DZ````'94,A#'A"3L````
M`````,>$)/````#PX=+#QX0D]`````````#'A"3X`````````,>$)/P`````
M````QX0D``$```````#'A"0$`0```````,>$)$@!````````@\00C80DP```
M`(E$)"R-A"3X````B40D*(VT)@````"#[`1H`(```/]T)!C_="0HBUPD%.@W
MO/__@\00A<")Q0^.\@$``(NT).@```"+O"3L````B>B)Z\'@`XGIP?L?B7PD
M)`'P@WPD)`")="0@B[PD]````(NT)/````!W!CE$)"!V!H/&`8/7`(F$).@`
M``")R(G:#ZS8'<'J'<>$).P``````````<:+A"0X`0``$=>)M"3P````B;PD
M]````(7`#X1?`0``OT`````IQSG]#T[]`T0D*(/L!%?_="084(M<)!3H);S_
M_XN$)$@!```!^(F$)$@!``"#Q!"#^$`/A1G___^+1"0L*?T#?"00Z&K!__^-
M=@"-O"<`````@_T_#X[9````@^U`B>[![@:-7@&)="0@BW0D+,'C!@'[C;0F
M`````(L'@\=`B80D^````(M'Q(F$)/P```"+1\B)A"0``0``BT?,B80D!`$`
M`(M'T(F$)`@!``"+1]2)A"0,`0``BT?8B80D$`$``(M'W(F$)!0!``"+1^")
MA"08`0``BT?DB80D'`$``(M'Z(F$)"`!``"+1^R)A"0D`0``BT?PB80D*`$`
M`(M'](F$)"P!``"+1_B)A"0P`0``BT?\B80D-`$``(GPZ(_`__\YWP^%3___
M_XMT)"#!Y@8I]6I$55?_="0TBUPD%.@]NO__B:PD2`$``(/$$.G^_?__C;8`
M````BWPD$.GO_O__C;0F`````(/L#/]T)"B+7"04Z$B[__^+A"0``0``BYPD
M^````(NT)/P```"+E"0$`0``B40D((G8#ZSP`XE4)"2#X#^-4`'&A`0(`0``
M@(/$$(/Z.`^/E0(``+@X````,?\IT`-4)"B#^`0/@],"``"%P'0+J`+&`@`/
MA8\#``"+?"00BVPD%(B\)#8!``"(G"0W`0``B?@/K.@8B(0D,`$``(GX#ZSH
M$(B$)#$!``")^(BD)#(!``"(A"0S`0``B=@/K/`8B(0D-`$``(G8#ZSP$(B$
M)#4!``"+1"0LZ&R___^+M"3`````B[PDQ````(M4)`2)\0^L^1B-DFR4__^(
MC"0_`0``#[;!B?$/K/D0B[PDS````(B,)$`!``")\8NT),@```"(K"1!`0``
MB(PD0@$``(GQ#ZSY&(B,)$,!``")\0^L^1"+O"34````B(PD1`$``(GQB[0D
MT````(BL)$4!``"(C"1&`0``B?$/K/D8B(PD1P$``(GQ#ZSY$(N\)-P```"(
MC"1(`0``B?&+M"38````B*PD20$``(B,)$H!``")\0^L^1B(C"1+`0``B?$/
MK/D0B[PDY````(B,)$P!``")\8NT).````"(K"1-`0``B(PD3@$``(GQ#ZSY
M&(B,)$\!``")\0^L^1"-O"1[`0``B(PD4`$``(GQC;0D0`$``(BL)%$!``"(
MC"12`0``C8PD4P$``(E,)!R)S8E\)!")]XG6Z0T```"-M"8`````#[8'@\<!
M@^P,4%9J_VH!58M<)"2#Q0+HS+G__X/$(#EL)!!UVXM<)`3&A"1[`0```(V#
MO93__U"-@XF4____="0@_W0D(/]T)!10:O]J`?]T)"CHD+G__X/$(.GO^?__
MD(VT)@````"+1"00BU`$A=(/A`'Y__^#[`Q2BWPD%(E4)"")^^@NN/__@\00
M@_@##X;B^/__BU0D$(V_A)3__[D%````C70"_/.F#T54)!R)5"0<Z;_X__^+
M3"0HN$`````!T2G0=`TQTL8$$0"#P@$YPG+UBT0D+.@ZO?__BWPD*+D.````
M,<#SJ^E9_?__@^P(4/]T)!2+1"0@_S"+7"08C8,8E?__Z6OV__^-2@3'`@``
M``#'1`+\`````(/A_"G*`<*#XOR#^@0/@AC]__^#XOPQP(D\`8/`!#G0<O;I
M!/W__X"\)'X!``!!#X6-^?__@+PD?P$``$,/A7_Y__^`O"2``0``2`^%<?G_
M_X"\)($!``!%#X5C^?__:@)J_VK&BVPD*%6+="04B?/H];7__X/$#&HIBWPD
M&%=5Z&6V__^-AKV4__]0C8:)E/__5_]T)##_="0D4&K_:@'_="0XZ"&X__^#
MQ##I@/C__XGVC;PG`````#')9HE,`O[I9?S__^B_!```ZPV0D)"0D)"0D)"0
MD)"055=64^@7N___@</'<0``@^PXB[O\````9:$4````B40D*#'`_S?HU;7_
M_UW_-XG&Z,NU__\/ME9HB%!IC40D*(E$)!R)PHV#H)/__^BOX___@\00A<!T
M"8`X,0^$KP(``.C*[O__@^P,_S?HD+7__XV3MY3__VH+:@%24.@_M?__@\0@
MA<`/A/X```"+0`R#NW@1```!BR^+0!B)1"0(#X[G````,?;K/8VT)@````"+
M0@R#[`B-5@%0BX-T$0``_S20B50D%.B4M___@\00A<"+BW@1``!U;XM4)`2-
M0@&)UCG!?F*#[`Q5Z!&U__]J`%;_="0@4.@4MO__@\0@A<!T/8L0BR^+0@@E
M``0@`#T`!```=)J)5"0$@^P,5>C=M/__:@)J`(M4)!Q24.A.M___BR^#Q"#I
M=____XUT)@"+BW@1``"++XU!_SGP=3V#^0%^.(GHO@$```"+;"0(ZPF-M"8`
M````BP>#[`R#Q@%0Z(JT__]:6550Z#&T__^#Q!`YLW@1``!_WHLO@^P,5>AK
MM/__C9.\E/__:@-J`5)0Z!JT__^#Q""%P(G&=#*+0`R#[`R+*/\WZ$*T__^-
MD[Z4__^#Q`Q255#H`;3__XM&#(/$$(LP]D8*0`^%;P$``(/L#/\WZ!6T__^-
MD\.4__]J`VH!4E#HQ+/__X/$((7`B<9T-HM4)`R-@VZ3___H[.'__X7`B<4/
MA`(!``"+1@R#[`R+,/\WZ-.S__^#Q`Q55E#HF+/__X/$$(/L#/\WZ+NS__^-
MD\64__^#Q`QJ`5)0Z+FR__^)QEC_-^B?L___C9/:E/__@\0,4E90Z%ZS__]:
M_S?HAK/__XM4)!S&0&D`C8-ED___Z'/A__^#Q!"%P(G&B8-\$0``=$2#[`AH
MP`$``%;H1K+__XU0`8/$$(/Z`78)@_@1#X6R````BT0D'&4S!10````/A9P`
M``"#Q"Q;7E]=PXGVC;PG`````(/L#/^S=!$``.BB[___@\00A<")QHF#?!$`
M`'6?C8.HE?__@^P,4.C$M/__C70F`(!X`0`/A$S]___I0OW__Y"+@W01``"#
M[`R+*(M&#(LP_S?HR;+__XGJB?#H8.;__X/$$.GS_O__D(VT)@````"#[`S_
M-^BFLO__65U64.@-M/__@\00Z7;^___H0`$``%"+@W01``!6_S"-@\R5__]0
MZ$JT__^-=@"-O"<`````5U93BUPD$.AC````@<<T;@``@^P,4^B5ZO__#[80
M@\00B<:$TG09B?:-O"<`````@\`!@/HO#[80#T3PA-)U\.@K[?__A=MT&(7`
M=!2`.P!T#XV_<93__[D$````\Z9T!%M>7\.)V%M>7^FAX___BSPDPV:09I!F
MD&:09I!FD)!3Z`JW__^!P[IM``"#[`C_LS0!``#_="0<_W0D'/]T)!SH2K'_
M_X/$&%O#9I!FD)!55U93Z->V__^!PX=M``"#[`R+;"0HC;/T_O__Z#NP__^-
M@_#^__\IQL'^`H7V="4Q_XVV`````(/L!%7_="0L_W0D+/^4N_#^__^#QP&#
MQ!`Y_G7C@\0,6UY?7<.-=@#SPV:09I!FD&:09I!FD&:04^AJMO__@<,:;0``
M@^P(Z+RR__]3@^P(Z%.V__^!PP-M``"#Q`A;PP,````!``(`+BX`)7,O)7,`
M+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]0
M4D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`'!A
M<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q
M+C`T-0`M90`M+0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`````'!E<FQX<VDN8P```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC
M;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^
M9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P
M;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E
M*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D
M;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S
M970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F
M9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z
M("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I
M92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D
M;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N
M<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE
M('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S
M="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K
M(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&
M2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L
M("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q
M=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B
M)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE
M(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@
M)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L
M<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\
M?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@
M>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T
M.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME
M>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I
M;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE
M+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@
M)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@
M)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@
M)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E
M*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@
M)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS
M.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@
M)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D
M<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A
M<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<
M,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I
M(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO
M861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S
M>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD
M9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*
M?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ
M<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB
M:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M
M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*
M96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B
M8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN
M="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV
M('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U
M<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=0
M05)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U
M8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*``$;`SOP````'0```*QP__\,`0``?'3__S`!``",
M=/__#`T```QX__]$`0``[)___X@!``"LH/__[`$``#RA__\D`@``C*/__Z0"
M``#\I/__7`,``(RE__^L`P``?*;__T@$``"\IO__>`0``!RG___$!```W*?_
M_U0%``#LI___:`4``/RI__]0!@``+*K__V0&```<J___R`8``.RL__\`!P``
M;*W__R0'``"LK?__4`<``'RN__^\!P``[+O__U`+``!\O___Q`P``.N___]4
M#0``_+___V@-```LP/__E`T``(S`___@#0``G,#___0-```4``````````%Z
M4@`!?`@!&PP$!(@!```@````'````)AO___0`P````X(1@X,2@\+=`1X`#\:
M.RHR)"(0````0````$1S__\0`````````$````!4````P';__]\G````00X(
MA0)!#@R'`T0.$(8$00X4@P5&#J`&`\@G"@X40<,.$$'&#@Q!QPX(0<4.!$$+
M````8````)@```!<GO__O`````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)!
M#C1!#CA$#CQ!#D!(#C!7"@X40\,.$$'&#@Q!QPX(0<4.!$(+;@H.%$/##A!!
MQ@X,0<<."$'%#@1$"S0```#\````N)[__X(`````00X(AP)!#@R&`T,.$(,$
M3@X@`F8*#A!!PPX,0<8."$''#@1!"P``?````#0!```0G___2P(```!!#@B%
M`D$.#(<#0PX0A@1!#A2#!5`.3%<.4$@.0%D.3$,.4$@.0`)/#DQ-#E!(#D`"
M>`H.%$'##A!!Q@X,0<<."$'%#@1'"P)<#DQ+#E!(#D!2#D1!#DA)#DQ%#E!0
M#D!C#DA!#DQ!#E!0#D````"T````M`$``."@__]J`0```$$."(4"00X,AP-#
M#A"&!$$.%(,%40Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2`M##JP!00ZP`4P.
MH`%;#JP!1`ZP`4@.H`%P#JP!00ZP`68.K`%!#J@!2PZL`4$.L`%!#K0!0@ZX
M`4(.O`%!#L`!2`ZD`44.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!
M00ZP`4@.H`%-#JP!1`ZP`5`.H`$`3````&P"``"8H?__A0````!!#@B&`D$.
M#(,#4`Z$`5$.B`%!#HP!0@Z0`4@.@`%N"@X,0<,."$'&#@1""TL.B`%"#HP!
M00Z0`4@.@`$```"8````O`(``-BA___G`````$$."(4"00X,AP-##A"&!$$.
M%(,%40[$(%@.R"!+#LP@00[0($@.P"!C#L0@00[(($(.S"!!#M`@2`[`($L.
MS"!!#M`@1@[4($$.V"!!#MP@00[@($@.P"!6"@X40<,.$$'&#@Q!QPX(0<4.
M!$<+2P[,($$.T"!(#L0@1`[(($$.S"!!#M`@2`[`(``L````6`,``"RB__\[
M`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP2`X(0<,.!`!(````B`,``#RB
M__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"#B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ!#C!(#@Q!PPX(0<8.!```C````-0#``!0HO__N0````!!#@B%`D$.
M#(<#00X0A@1!#A2#!5$.L$!=#KA`00Z\0$$.P$!'#L1`10[(0$(.S$!%#M!`
M2`ZT0$4.N$!(#KQ`00[`0$@.L$!,#KQ`00[`0$@.L$!)#K1`00ZX0$$.O$!!
M#L!`30ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$00L`$````&0$``"`HO__!0``
M``````#D````>`0``'RB__\%`@```$$."(4"00X,AP-!#A"&!$$.%(,%40ZP
M(7D.N"%$#KPA00[`(4@.L"%Q"@X40<,.$$'&#@Q!QPX(0<4.!$@+0PZ\(40.
MP"%&#KPA00ZX(4\.O"%!#L`A2`ZP(6D.N"%!#KPA00[`(4@.L"%+#KPA00[`
M(4@.L"%U#K0A1`ZX(4$.O"%'#L`A00[$(44.R"%"#LPA2`[0(4@.M"%$#K@A
M00Z\(4(.P"%(#K`A5PZX(40.O"%"#L`A2`ZP(0)!#K@A0@Z\(4$.P"%(#K`A
M5`Z\(4$.P"%(#K`A$````&`%``"DH___*@````````!@````=`4``,"C___G
M`````$$."(8"00X,@P-.#B!6#BQ!#C!,#B!F#BQ!#C!(#B!#"@X,0<,."$'&
M#@1)"UX.+$$.,$@.(&H.)$$.*$$.+$<.,$@.($4*#@Q!PPX(0<8.!$<+-```
M`-@%``!,I/__Q`$```!!#@B'`D$.#(8#00X0@P1.#D`#8`$*#A!!PPX,0<8.
M"$''#@1$"P`@````$`8``.2E__]V`````$$."(,"3@X@9PH."$'##@1)"P`H
M````-`8``$"F__\T`````$$."(,"3@X02`X<00X@2`X020H."$'##@1&"V@`
M``!@!@``5*;__\<`````00X(A0)!#@R'`T$.$(8$00X4@P5.#C!M#CA!#CQ!
M#D!(#C!'#CQ!#D!F#C1!#CA!#CQ'#D!!#D1"#DA"#DQ!#E!.#C!I"@X40<,.
M$$'&#@Q!QPX(0<4.!$$+`)`#``#,!@``N*;__V$-````00X(A0)!#@R'`T$.
M$(8$00X4@P51#J"#`@+J#JR#`D$.L(,"7@Z@@P)I#JR#`D0.L(,"00ZT@P)"
M#KB#`D(.O(,"00[`@P)/#J"#`@)+#JR#`D$.L(,"3`Z@@P("@PZL@P)(#K"#
M`DT.M(,"3PZX@P)+#KR#`D<.P(,"00[$@P)"#LB#`D(.S(,"10[0@P)(#JB#
M`D4.K(,"1`ZP@P)(#J"#`E@.I(,"00ZH@P)$#JR#`D(.L(,"3`Z@@P)=#JR#
M`D0.L(,"1@ZT@P)+#KB#`D@.O(,"0@[`@P)(#J"#`G8.K(,"00ZP@P),#J"#
M`ET.K(,"00ZP@P)@#J"#`F(*#A1!PPX00<8.#$''#@A!Q0X$1@MQ#JR#`D(.
ML(,"6`Z@@P)(#JR#`D$.L(,"3`Z@@P("0@ZL@P)!#K"#`E\.H(,"2PZL@P)!
M#K"#`DH.K(,"00ZH@P)!#JR#`D8.L(,"3`Z@@P)+#JR#`D4.L(,"3@Z@@P("
M0@ZH@P)"#JR#`D0.L(,"4`Z@@P)K#J2#`D$.J(,"2@ZL@P)$#K"#`D<.M(,"
M0@ZX@P)"#KR#`D0.P(,"2`Z@@P)J#JR#`D0.L(,"00ZT@P)!#KB#`D0.O(,"
M1`[`@P)!#L2#`D(.R(,"0@[,@P)!#M"#`DP.H(,"0PZH@P)%#JR#`D$.L(,"
M3`Z@@P)(#JR#`D0.L(,"9PZ@@P)=#J2#`D(.J(,"0@ZL@P)%#K"#`DX.I(,"
M0@ZH@P),#JR#`D$.L(,"2`Z@@P):#J2#`D(.J(,"0@ZL@P)$#K"#`@*Q#J"#
M`F`.I(,"10ZH@P)$#JR#`D0.L(,"3`Z@@P("H`ZD@P)!#JB#`D0.K(,"00ZP
M@P)<#J"#`@,&`0ZD@P)!#JB#`D$.K(,"1`ZP@P)3#J"#`EX.K(,"1`ZP@P("
M1`Z@@P(#[@$.K(,"00ZP@P)!#K2#`D(.N(,"0@Z\@P)!#L"#`D\.H(,"60ZD
M@P)*#JB#`D0.K(,"1`ZP@P)!#K2#`D(.N(,"0@Z\@P)$#L"#`D@.H(,"7PZL
M@P)!#K"#`E(.H(,"`F8*#JB#`D$.K(,"1`ZP@P)&#K2#`D\+`G(.I(,"0@ZH
M@P)"#JR#`D4.L(,"3@ZD@P)"#JB#`D4.K(,"00ZP@P),#K2#`D<.N(,"1`Z\
M@P)$#L"#`D$.Q(,"0@[(@P)"#LR#`D0.T(,"2`Z@@P)P`0``8`H``)2P__^&
M`P```$$."(4"00X,AP-!#A"&!$$.%(,%3@Y,5`Y01@Y,0@Y09@Y`50Y,0@Y0
M30Y40@Y800Y<00Y@2`Y`<@Y(1`Y,20Y03`Y`6@Y,00Y01PY400Y81`Y<00Y@
M2`Y`7@Y,00Y01PY40@Y810Y<00Y@2@Y`=@Y,1`Y01@Y,00Y(00Y,00Y02`Y`
M30Y,00Y030Y40@Y800Y<00Y@2`Y`3`Y,1`Y03@Y$00Y(00Y,00Y02PY`3PY,
M0@Y030Y40@Y800Y<00Y@2`Y`90Y,1`Y02`Y$00Y(00Y,00Y02`Y`0PY,0@Y0
M3@Y$0@Y(00Y,00Y02`Y,0@Y03@Y$00Y(00Y,00Y01@Y,0@Y06PY`3PY(10Y,
M00Y02PY`8@H.%$'##A!!Q@X,0<<."$'%#@1*"T,*#DQ&#E!(#D!5#DQ!#E!)
M"UD.3$D.4%$.0%`.3$(.4$8.3$$.2$$.3$$.4$@.0$L.1$<.2$(.3$<.4`!$
M````U`L``+"R__]O`````$$."(<"00X,A@-!#A"#!%(.'$$.($L.$`)!"L,.
M#$'&#@A!QPX$00M#PPX,0<8."$''#@0```!$````'`P``'AG__\\`@```$0,
M`0!'$`4"=0!&#P-U<`80!P)U?!`&`G5X$`,"=70#=P$*P0P!`$'#0<9!QT'%
M0PP$!$$+```0````9`P``(^R__\$`````````"@```!X#```C++__RL`````
M00X(@P).#A!&#A1$#AA$#AQ$#B!(#@A!PPX$2````*0,``"0LO__70````!!
M#@B%`D$.#(<#00X0A@1!#A2#!4X.(&D.)$$.*$0.+$0.,$T.($<.%$'##A!!
MQ@X,0<<."$'%#@0``!````#P#```I++__P(`````````&`````0-``"@LO__
M%`````!!#@B#`DX.$```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````$!D``,`8```!`````0````$```#+`0``
M`0```!H"```,````G!$```T```#$80``&0```,#-```;````!````!H```#$
MS0``'`````0```#U_O]OK`$```4```#L"```!@```(P"```*````V00```L`
M```0````%0`````````#````T,X```(```#@`0``%````!$````7````O`\`
M`!$````T#P``$@```(@````3````"````!X````(````^___;P$```C^__]O
ME`X``/___V\"````\/__;\8-``#Z__]O!0``````````````````````````
M``````````````````````````````#(S0````````````#6$0``YA$``/81
M```&$@``%A(``"82```V$@``1A(``%82``!F$@``=A(``(82``"6$@``IA(`
M`+82``#&$@``UA(``.82``#V$@``!A,``!83```F$P``-A,``$83``!6$P``
M9A,``'83``"&$P``EA,``*83``"V$P``QA,``-83``#F$P``]A,```84```6
M%```)A0``#84``!&%```5A0``&84``!V%```AA0``)84``"F%```MA0``,84
M``#6%```YA0``/84```&%0``%A4``"85```V%0``1A4``%85``!F%0``=A4`
M`(85````````````````````````````````````````````````````````
M``````````"@%0````````30``#_____X&0``$=#0SH@*%5B=6YT=2`W+C,N
M,"TR,W5B=6YT=3(I(#<N,RXP`$=#0SH@*%5B=6YT=2`W+C,N,"TQ-G5B=6YT
M=3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN
M;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M``````````````````````L````!`````@```%0!``!4`0``$P``````````
M`````0`````````3````!P````(```!H`0``:`$``"````````````````0`
M````````(0````<````"````B`$``(@!```D```````````````$````````
M`#0```#V__]O`@```*P!``"L`0``X`````4`````````!`````0````^````
M"P````(```",`@``C`(``&`&```&`````0````0````0````1@````,````"
M````[`@``.P(``#9!``````````````!`````````$X```#___]O`@```,8-
M``#&#0``S`````4``````````@````(```!;````_O__;P(```"4#@``E`X`
M`*`````&`````@````0`````````:@````D````"````-`\``#0/``"(````
M!0`````````$````"````',````)````0@```+P/``"\#P``X`$```4````6
M````!`````@```!\`````0````8```"<$0``G!$``",```````````````0`
M````````=P````$````&````P!$``,`1``#0`P`````````````0````!```
M`((````!````!@```)`5``"0%0``$```````````````"`````@```"+````
M`0````8```"@%0``H!4``"1,`````````````!``````````D0````$````&
M````Q&$``,1A```4```````````````$`````````)<````!`````@```-AA
M``#880``/#\`````````````!`````````"?`````0````(````4H0``%*$`
M`/0```````````````0`````````K0````$````"````"*(```BB```@#0``
M```````````$`````````+<````.`````P```,#-``#`O0``!```````````
M````!`````0```##````#P````,```#$S0``Q+T```0```````````````0`
M```$````SP````8````#````R,T``,B]```(`0``!@`````````$````"```
M`(8````!`````P```-#.``#0O@``,`$`````````````!`````0```#8````
M`0````,`````T````,```!````````````````0`````````W@````@````#
M````(-```!#````T$``````````````@`````````.,````!````,```````
M```0P```2````````````````0````$````!`````P``````````````6,``
5`.P```````````````$`````````
